
def randomize_field_names(query):
    """
    Randomly rename fields in the query results from a Peewee model.
    """
    from peewee import *

    # Assuming 'Model' is a Peewee model class
    class Model(BaseModel):
        field1 = CharField()
        field2 = IntegerField()
        field3 = BooleanField()

    # Create a database connection
    database = SqliteDatabase(':memory:')
    database.connect()
    database.create_tables([Model])

    # Insert some data
    Model.create(field1='value1', field2=2, field3=True)

    # Perform a query
    results = Model.select()

    # Randomly rename fields
    field_names = list(results.column_names)
    renamed_fields = {field_names[i]: f"new_field_{i}" for i in range(len(field_names))}

    # Execute the query with renamed fields
    for result in results:
        new_fields = {renamed_fields[field]: value for field, value in result.items()}
        print(new_fields)

    # Close the database connection
    database.close()

    return renamed_fields



